<?php

define('RADAR_PAYMENT_NAME', 'DSK Bank');

define('RADAR_PROD_URL' , 'https://epg.dskbank.bg/payment/rest/');
define('RADAR_TEST_URL' , 'https://uat.dskbank.bg/payment/rest/');

define('RADAR_ENABLE_LOGGING', true);
define('RADAR_ENABLE_CART_OPTIONS', false);
define('RADAR_MEASUREMENT_NAME', 'pcs.'); //FFD v1.05
define('RADAR_MEASUREMENT_CODE', 0);
define('RADAR_ENABLE_CALLBACK', true);

define('RADAR_CURRENCY_CODES', serialize(array(
    'USD' => '840',
    'UAH' => '980',
    'RON' => '946',
    'KGS' => '417',
    'JPY' => '392',
    'GBR' => '826',
    'EUR' => '978',
    'CNY' => '156',
)));

//this close tag must be here -> ?>
<?php
class DSK
{
public $prod_url;
public $test_url;
public $alternative_domain = null;
public $dsk_enable_cart_options = RADAR_ENABLE_CART_OPTIONS;
public $dsk_enable_refund_options;
public $logging = RADAR_ENABLE_LOGGING;
public $currency_code2num;
public $language = 'en';
public $version = '3.1.6';
public $token;
public $login;
public $password;
public $mode;
public $stage;
public $currency;
public $ofd_status;
public $FFDVersion;
public $paymentMethodType;
public $paymentObjectType;
private $deliveryPaymentMethodType;
public $taxSystem;
public $taxType;
public $discountHelper;
public $allowCallbacks = RADAR_ENABLE_CALLBACK;
public $enable_dsk_cacert = true;
public $dsk_cacert_path = null;
public $enable_back_url_settings = false;
public $api_version = 1;
public function __construct()
{
$this->test_url = RADAR_TEST_URL;
$this->prod_url = RADAR_PROD_URL;
if (defined('RADAR_API_VERSION')) {
$this->api_version = RADAR_API_VERSION;
}
if (defined('RADAR_PROD_URL_ALTERNATIVE_DOMAIN')) {
$this->alternative_domain = RADAR_PROD_URL_ALTERNATIVE_DOMAIN;
}
if (defined('RADAR_PROD_URL_ALTERNATIVE_DOMAIN') && defined('RADAR_PROD_URL_ALT_PREFIX')) {
$this->allowCallbacks = false;
}
$this->currency_code2num = unserialize(RADAR_CURRENCY_CODES);
if ($this->dsk_enable_cart_options === true){
$this->library('DSKDiscount');
$this->discountHelper = new DSKDiscount();
}
if (file_exists(DIR_SYSTEM . "library/dsk_cacert.cer")) {
$this->enable_dsk_cacert = true;
$this->dsk_cacert_path = DIR_SYSTEM . "library/dsk_cacert.cer";
} else {
$this->enable_dsk_cacert = false;
}
if (defined('RADAR_ENABLE_REFUND_TAB') && RADAR_ENABLE_REFUND_TAB === true) {
$this->dsk_enable_refund_options = true;
} else {
$this->dsk_enable_refund_options = false;
}
if (defined('RADAR_ENABLE_BACK_URL_SETTINGS') && RADAR_ENABLE_BACK_URL_SETTINGS === true) {
$this->enable_back_url_settings = true;
}
}
/**
* @return string
*/
public function getTestUrl()
{
return $this->test_url;
}
/**
* @return string
*/
public function getProdUrl()
{
return $this->prod_url;
}
/**
* @return string
*/
public function getAlternativeDomain()
{
return $this->alternative_domain;
}
/**
* @return mixed
*/
public function getFFDVersion()
{
return $this->FFDVersion;
}
/**
* @param $delivery
* @return mixed
*/
public function getPaymentMethodType($delivery = false)
{
if ($delivery) {
return $this->deliveryPaymentMethodType;
}
return $this->paymentMethodType;
}
/**
* @return mixed
*/
public function getPaymentObjectType()
{
return $this->paymentObjectType;
}
/**
* @return string
*/
public function getDefaultMeasurement()
{
if ($this->FFDVersion == "v1_05") {
return RADAR_MEASUREMENT_NAME;
}
return RADAR_MEASUREMENT_CODE;
}
/**
* @param $property
* @param $value
* @return $this
*/
public function __set($property, $value)
{
if (property_exists($this, $property)) {
$this->$property = $value;
}
return $this;
}
/**
* @param $data
* @param $action_address
* @param array $headers
* @return string
*/
public function _sendGatewayData($data, $action_address, $headers = array())
{
$curl_opt = array(
CURLOPT_HTTPHEADER => $headers,
CURLOPT_VERBOSE => true,
CURLOPT_SSL_VERIFYHOST => false,
CURLOPT_URL => $action_address,
CURLOPT_RETURNTRANSFER => true,
CURLOPT_POST => true,
CURLOPT_POSTFIELDS => $data,
CURLOPT_HEADER => true,
);
$ssl_verify_peer = false;
if ($this->dsk_cacert_path != null && $this->enable_dsk_cacert == true) {
$ssl_verify_peer = true;
$curl_opt[CURLOPT_CAINFO] = $this->dsk_cacert_path;
}
$curl_opt[CURLOPT_SSL_VERIFYPEER] = $ssl_verify_peer;
$ch = curl_init();
curl_setopt_array($ch, $curl_opt);
$response = curl_exec($ch);
if ($response === false) {
$error = array('errorCode' => 999, "errorMessage" => curl_error($ch));
return json_encode($error);
}
$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
curl_close($ch);
return substr($response, $header_size);
}
/**
*
* @param string $order_number
* @param integer $amount
* @param integer $currency_code
* @param string $return_url
* @param null $orderBundle
* @return mixed[]
*/
public function register_order($order_number, $amount, $return_url, $currency_code = 643, $orderBundle = null)
{
$data = array(
'orderNumber' => $order_number . "_" . time(),
'amount' => $amount,
'returnUrl' => $return_url,
'jsonParams' => json_encode(
[
'CMS:' => 'Opencart ' . VERSION,
'Module-Version: ' => $this->version
]
),
);
if ($this->currency != 0) {
$data['currency'] = $this->currency;
} else {
$data['currency'] = $currency_code;
}
if ($this->ofd_status && !empty($orderBundle)) {
$data['taxSystem'] = $this->taxSystem;
$data['orderBundle']['orderCreationDate'] = date('c');
$data['orderBundle'] = json_encode($orderBundle);
}
return $this->gateway($this->stage == 'two' ? 'registerPreAuth.do' : 'register.do', $data);
}
/**
*
* @param string $method
* @param mixed[] $data
* @return mixed[]
*/
public function gateway($method, $data) {
if (!empty($this->token)) {
$decoded_credentials = base64_decode($this->token);
list($l, $p) = explode(':', $decoded_credentials);
$data['userName'] = $l;
$data['password'] = $p;
} else {
$data['userName'] = $this->login;
$data['password'] = $this->password;
}
if ($this->mode == 'test') {
$url = $this->test_url;
} else {
$url = $this->prod_url;
if (defined('RADAR_PROD_URL_ALTERNATIVE_DOMAIN') && defined('RADAR_PROD_URL_ALT_PREFIX')) {
if (substr($this->login, 0, strlen(RADAR_PROD_URL_ALT_PREFIX)) == RADAR_PROD_URL_ALT_PREFIX) {
$pattern = '/^https:\/\/[^\/]+/';
$url = preg_replace($pattern, rtrim(RADAR_PROD_URL_ALTERNATIVE_DOMAIN, '/'), $url);
}
}
}
$curl_opt = array(
CURLOPT_HTTPHEADER => array('CMS: OpenCart ' . VERSION, 'Module-Version: ' . $this->version),
CURLOPT_VERBOSE => true,
CURLOPT_SSL_VERIFYHOST => false,
CURLOPT_URL => $url.$method,
CURLOPT_RETURNTRANSFER => true,
CURLOPT_POST => true,
CURLOPT_POSTFIELDS => $data,
CURLOPT_HEADER => true,
);
$ssl_verify_peer = false;
if ($this->dsk_cacert_path != null && $this->enable_dsk_cacert == true) {
$ssl_verify_peer = true;
$curl_opt[CURLOPT_CAINFO] = $this->dsk_cacert_path;
}
$curl_opt[CURLOPT_SSL_VERIFYPEER] = $ssl_verify_peer;
$ch = curl_init();
curl_setopt_array($ch, $curl_opt);
$response = curl_exec($ch);
if ($response === false) {
$error = array('errorCode' => 999, "errorMessage" => curl_error($ch));
return json_encode($error);
}
$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
curl_close($ch);
return substr($response, $header_size);
}
/**
*
* @param string $url
* @param string $method
* @param mixed[] $request
* @param mixed[] $response
* @return integer
*/
public function logger($url, $method, $request, $response) {
$this->library('log');
$file_name = "oc23x_dsk_" . date("y-m") . ".log";
$logger = new Log($file_name);
$logger->write("REQUEST: ".json_encode($request). "\nRESPONSE: ".$response."\n\n");
}
/**
*
* @param string $orderId
* @return mixed[]
*/
public function get_order_status($orderId) {
if ($this->mode == 'test') {
$action_address = $this->test_url . "getOrderStatusExtended.do";
} else {
$action_address = $this->prod_url . "getOrderStatusExtended.do";
}
if (!empty($this->token)) {
$decoded_credentials = base64_decode($this->token);
list($l, $p) = explode(':', $decoded_credentials);
$data['userName'] = $l;
$data['password'] = $p;
} else {
$data['userName'] = $this->login;
$data['password'] = $this->password;
}
$data['orderId'] = $orderId;
return $this->_sendGatewayData($data, $action_address);
}
public function _allowCallback() {
if (defined('RADAR_PROD_URL_ALTERNATIVE_DOMAIN')
&& defined('RADAR_PROD_URL_ALT_PREFIX')
&& (substr($this->login, 0, strlen(RADAR_PROD_URL_ALT_PREFIX)) != RADAR_PROD_URL_ALT_PREFIX)
) {
return false;
}
return RADAR_ENABLE_CALLBACK;
}
private function library($library) {
$file = DIR_SYSTEM . 'library/' . str_replace('../', '', (string)$library) . '.php';
if (file_exists($file)) {
include_once($file);
} else {
trigger_error('Error: Could not load library ' . $file . '!');
exit();
}
}
}